==> hs-ConfigFile-1.0.6p10.tgz: lib/ghc/ConfigFile-1.0.6/register.sh <==
#!/bin/sh
echo 'name: ConfigFile
version: 1.0.6
id: ConfigFile-1.0.6-62f7a7150abb5e3758778519a40c3a17

license: LGPL
copyright: Copyright (c) 2004-2010 John Goerzen
maintainer: John Goerzen <jgoerzen@complete.org>
stability: Stable
homepage: http://software.complete.org/configfile
package-url:
description: Parser and writer for handling sectioned config files in
             Haskell.
             .
             The ConfigFile module works with configuration files in a standard
             format that is easy for the user to edit, easy for the programmer
             to work with, yet remains powerful and flexible.  It is inspired by,
             and compatible with, Python'\''s ConfigParser module.  It uses files
             that resemble Windows .INI-style files, but with numerous
             improvements.
             .
             ConfigFile provides simple calls to both read and write config files.
             It'\''s possible to make a config file parsable by this module,
             the Unix shell, and make.
category: Parsing
author: John Goerzen
pkgpath: devel/hs-ConfigFile
exposed: True
exposed-modules: Data.ConfigFile Data.ConfigFile.Types
                 Data.ConfigFile.Parser
hidden-modules: Data.ConfigFile.Lexer
import-dirs: /usr/local/lib/ghc/ConfigFile-1.0.6
library-dirs: /usr/local/lib/ghc/ConfigFile-1.0.6
hs-libraries: HSConfigFile-1.0.6
extra-libraries:
extra-ghci-libraries:
include-dirs:
includes:
depends: MissingH-1.1.0.3-a22bb72539d5cdf816ea8c454d0ba212
         base-4.3.1.0-e1ba2d2213b66179f3e0c901a27d3a96
         containers-0.4.0.0-8781485edb2ac0db733a9f9c72e27945
         haskell98-1.1.0.1-94f7a5cdbf7a4c3cb91e841ae24bf4c0
         mtl-2.0.1.0-91f62d81c946aa60137dcc008e554a3a
         parsec-3.1.1-e9e6a217dbe32c1d9695e23a4f5f794b
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/hs-ConfigFile-1.0.6/html/ConfigFile.haddock
haddock-html: /usr/local/share/doc/hs-ConfigFile-1.0.6/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"

==> hs-ConfigFile-1.1.1.tgz: lib/ghc/ConfigFile-1.1.1/register.sh <==
#!/bin/sh
echo 'name: ConfigFile
version: 1.1.1
id: ConfigFile-1.1.1-8824a2e904f3cc54036c5739ce9c61dd

license: LGPL
copyright: Copyright (c) 2004-2010 John Goerzen
maintainer: John Goerzen <jgoerzen@complete.org>
stability: Stable
homepage: http://software.complete.org/configfile
package-url:
description: Parser and writer for handling sectioned config files in
             Haskell.
             .
             The ConfigFile module works with configuration files in a standard
             format that is easy for the user to edit, easy for the programmer
             to work with, yet remains powerful and flexible.  It is inspired by,
             and compatible with, Python'\''s ConfigParser module.  It uses files
             that resemble Windows .INI-style files, but with numerous
             improvements.
             .
             ConfigFile provides simple calls to both read and write config files.
             It'\''s possible to make a config file parsable by this module,
             the Unix shell, and make.
category: Parsing
author: John Goerzen
pkgpath: devel/hs-ConfigFile
exposed: True
exposed-modules: Data.ConfigFile Data.ConfigFile.Types
                 Data.ConfigFile.Parser Data.ConfigFile.Monadic
hidden-modules: Data.ConfigFile.Lexer
import-dirs: /usr/local/lib/ghc/ConfigFile-1.1.1
library-dirs: /usr/local/lib/ghc/ConfigFile-1.1.1
hs-libraries: HSConfigFile-1.1.1
extra-libraries:
extra-ghci-libraries:
include-dirs:
includes:
depends: MissingH-1.1.1.0-88fc4e10f4dbf5b970f2421280609d73
         base-4.3.1.0-ee15f259a627d341af7c80a17e8b0e66
         containers-0.4.0.0-f1307d32d8f4b51a1487c01f0997b6d9
         mtl-2.0.1.0-3e464329054b7660133198d73c31aca5
         parsec-3.1.1-bf92fff0e29c344f3b78cfddb556a5b9
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/hs-ConfigFile-1.1.1/html/ConfigFile.haddock
haddock-html: /usr/local/share/doc/hs-ConfigFile-1.1.1/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
